@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.15_07';
+our $VERSION = '0.25_01';
 
 use AnyEvent::Stomper::Frame;
 use AnyEvent::Stomper::Error;
@@ -934,7 +934,7 @@ AnyEvent::Stomper - Flexible non-blocking STOMP client
       print "Consumed: $body\n";
 
       $cv->send;
-    }
+    },
   );
 
   $cv->recv;
@@ -1119,7 +1119,7 @@ way to specify the command callback.
 
 If you want to receive C<RECEIPT> frame, you must specify C<receipt> header.
 The C<receipt> header can take the special value C<auto>. If it set, the
-receipt identificator will be generated automatically by the client. The
+receipt identifier will be generated automatically by the client. The
 C<RECEIPT> frame is passed to the command callback in first argument as the
 object of the class L<AnyEvent::Stomper::Frame>. If the C<receipt> header is
 not specified the first argument of the command callback will be C<undef>.
@@ -1128,10 +1128,11 @@ For commands C<SUBSCRIBE>, C<UNSUBSCRIBE>, C<DISCONNECT> the client
 automatically adds C<receipt> header for internal usage.
 
 The command callback is called in one of two cases depending on the presence of
-the C<receipt> header: when the command was successfully sent to the server or
-when the C<RECEIPT> frame will be received. If any error occurred during the
-command execution, the error object is passed to the callback in second
-argument. Error object is the instance of the class L<AnyEvent::Stomper::Error>.
+the C<receipt> header. First case, when the command was successfully sent to
+the server. Second case, when the C<RECEIPT> frame will be received. If any
+error occurred during the command execution, the error object is passed to the
+callback in second argument. Error object is the instance of the class
+L<AnyEvent::Stomper::Error>.
 
 The command callback is optional. If it is not specified and any error
 occurred, the C<on_error> callback of the client is called.
@@ -1241,7 +1242,7 @@ callback, this callback will be act as C<on_message> callback.
       my $body    = $msg->body;
 
       # message handling...
-    }
+    },
   );
 
 =head2 unsubscribe( [ %params ] [, $cb->( $receipt, $err ) ] )
@@ -1332,7 +1333,7 @@ The method C<begin> is used to start a transaction.
 
 The method C<commit> is used to commit a transaction.
 
-=head2 abort([ %params ] [, $cb->( $receipt, $err ) ] )
+=head2 abort( [ %params ] [, $cb->( $receipt, $err ) ] )
 
 The method C<abort> is used to roll back a transaction.
 
@@ -1468,7 +1469,7 @@ Sponsored by SMS Online, E<lt>dev.opensource@sms-online.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2016, Eugene Ponizovsky, SMS Online. All rights reserved.
+Copyright (c) 2016-2017, Eugene Ponizovsky, SMS Online. All rights reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
