@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.15_07';
+our $VERSION = '0.25_01';
 
 use AnyEvent::Stomper;
 use AnyEvent::Stomper::Error;
@@ -89,14 +89,6 @@ sub execute {
   }
 }
 
-sub get_node {
-  my $self = shift;
-  my $host = shift;
-  my $port = shift;
-
-  return $self->{_nodes_pool}{"$host:$port"};
-}
-
 sub nodes {
   my $self = shift;
   return values %{ $self->{_nodes_pool} };
@@ -125,7 +117,7 @@ sub on_error {
 sub force_disconnect {
   my $self = shift;
 
-  foreach my $node ( values %{ $self->{_nodes_pool} } ) {
+  foreach my $node ( $self->nodes ) {
     $node->force_disconnect;
   }
   $self->_reset_internals;
@@ -373,31 +365,30 @@ AnyEvent::Stomper::Cluster - The client for the cluster of STOMP servers
     id          => 'foo',
     destination => '/queue/foo',
 
-    { on_receipt => sub {
-        my $err = $_[1];
-
-        if ( defined $err ) {
-          warn $err->message . "\n";
-          $cv->send;
-
-          return;
-        }
-
-        $cluster->send(
-          destination => '/queue/foo',
-          body        => 'Hello, world!',
-        );
-      },
-
-      on_message => sub {
-        my $msg = shift;
-
-        my $body = $msg->body;
-        print "Consumed: $body\n";
+    on_receipt => sub {
+      my $err = $_[1];
 
+      if ( defined $err ) {
+        warn $err->message . "\n";
         $cv->send;
-      },
-    }
+
+        return;
+      }
+
+      $cluster->send(
+        destination => '/queue/foo',
+        body        => 'Hello, world!',
+      );
+    },
+
+    on_message => sub {
+      my $msg = shift;
+
+      my $body = $msg->body;
+      print "Consumed: $body\n";
+
+      $cv->send;
+    },
   );
 
   $cv->recv;
@@ -424,15 +415,29 @@ AnyEvent::Stomper::Cluster is the client for the cluster of STOMP servers.
     reconnect_interval => 5,
 
     on_node_connect => sub {
+      my $host = shift;
+      my $port = shift;
+
       # handling...
     },
 
     on_node_disconnect => sub {
+      my $host = shift;
+      my $port = shift;
+
       # handling...
     },
 
     on_node_error => sub {
       my $err = shift;
+      my $host = shift;
+      my $port = shift;
+
+      # error handling...
+    },
+
+    on_error => sub {
+      my $err = shift;
 
       # error handling...
     },
@@ -443,9 +448,9 @@ AnyEvent::Stomper::Cluster is the client for the cluster of STOMP servers.
 =item nodes => \@nodes
 
 Specifies the list of nodes. Parameter should contain array of hashes. Each
-hash should contain C<host> and C<port> elements. The client gets one random
-node from this list, connects to it and sends all frames to this node. If
-current active node fails, the client gets next node from the list.
+hash should contain C<host> and C<port> elements. At the start the client gets
+random node from this list, connects to it and sends all frames to this node.
+If current active node fails, the client gets next node from the list.
 
 =item login => $login
 
@@ -561,6 +566,12 @@ and host and port of the node on which an error occurred.
 
 Not set by default.
 
+=item on_error => $cb->( $err )
+
+The C<on_error> callback is called on command errors if the command callback
+is not specified. If the C<on_error> callback is not specified, the client
+just print an error messages to C<STDERR>.
+
 =back
 
 =head1 COMMAND METHODS
@@ -574,7 +585,7 @@ way to specify the command callback.
 
 If you want to receive C<RECEIPT> frame, you must specify C<receipt> header.
 The C<receipt> header can take the special value C<auto>. If it set, the
-receipt identificator will be generated automatically by the client. The
+receipt identifier will be generated automatically by the client. The
 C<RECEIPT> frame is passed to the command callback in first argument as the
 object of the class L<AnyEvent::Stomper::Frame>. If the C<receipt> header is
 not specified the first argument of the command callback will be C<undef>.
@@ -583,10 +594,14 @@ For commands C<SUBSCRIBE>, C<UNSUBSCRIBE>, C<DISCONNECT> the client
 automatically adds C<receipt> header for internal usage.
 
 The command callback is called in one of two cases depending on the presence of
-the C<receipt> header: when the command was successfully sent to the server or
-when the C<RECEIPT> frame will be received. If any error occurred during the
-command execution, the error object is passed to the callback in second
-argument. Error object is the instance of the class L<AnyEvent::Stomper::Error>.
+the C<receipt> header. First case, when the command was successfully sent to
+the server. Second case, when the C<RECEIPT> frame will be received. If any
+error occurred during the command execution, the error object is passed to the
+callback in second argument. Error object is the instance of the class
+L<AnyEvent::Stomper::Error>.
+
+The command callback is optional. If it is not specified and any error
+occurred, the C<on_error> callback of the client is called.
 
 If you want to track errors on particular nodes for particular command, you
 must specify C<on_node_error> callback in command method.
@@ -726,7 +741,7 @@ callback, this callback will be act as C<on_message> callback.
       my $body    = $msg->body;
 
       # message handling...
-    }
+    },
   );
 
 =head2 unsubscribe( [ %params ] [, $cb->( $receipt, $err ) ] )
@@ -817,13 +832,13 @@ The method C<begin> is used to start a transaction.
 
 The method C<commit> is used to commit a transaction.
 
-=head2 abort([ %params ] [, $cb->( $receipt, $err ) ] )
+=head2 abort( [ %params ] [, $cb->( $receipt, $err ) ] )
 
 The method C<abort> is used to roll back a transaction.
 
 =head2 disconnect( [ %params ] [, $cb->( $receipt, $err ) ] )
 
-A client can disconnect from the сurrent active node at anytime by closing the
+A client can disconnect from the current active node at anytime by closing the
 socket but there is no guarantee that the previously sent frames have been
 received by the node. To do a graceful shutdown, where the client is assured
 that all previous frames have been received by the node, you must call
@@ -869,10 +884,6 @@ Full list of error codes see in documentation on L<AnyEvent::Stomper>.
 
 =head1 OTHER METHODS
 
-=head2 get_node( $host, $port )
-
-Gets node by host and port.
-
 =head2 nodes()
 
 Gets all available nodes.
@@ -898,7 +909,7 @@ Sponsored by SMS Online, E<lt>dev.opensource@sms-online.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2016, Eugene Ponizovsky, SMS Online. All rights reserved.
+Copyright (c) 2016-2017, Eugene Ponizovsky, SMS Online. All rights reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
